"use strict";

exports.__esModule = true;
exports.GatsbyImageSharpFluid_withWebp_tracedSVG = exports.GatsbyImageSharpFluid_withWebp_noBase64 = exports.GatsbyImageSharpFluid_withWebp = exports.GatsbyImageSharpFluid_tracedSVG = exports.GatsbyImageSharpFluid_noBase64 = exports.GatsbyImageSharpFluidLimitPresentationSize = exports.GatsbyImageSharpFluid = exports.GatsbyImageSharpFixed_withWebp_tracedSVG = exports.GatsbyImageSharpFixed_withWebp_noBase64 = exports.GatsbyImageSharpFixed_withWebp = exports.GatsbyImageSharpFixed_tracedSVG = exports.GatsbyImageSharpFixed_noBase64 = exports.GatsbyImageSharpFixed = void 0;
var _gatsby = require("gatsby");
/* eslint-disable */

/**
 * The simplest set of fields for fixed sharp images
 * @type {Fragment}
 * @example
 * childImageSharp {
 *   fixed {
 *     ...GatsbyImageSharpFixed
 *     # ^ identical to using the following fields:
 *     # base64
 *     # width
 *     # height
 *     # src
 *     # srcSet
 *   }
 * }
 */
const GatsbyImageSharpFixed = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed on ImageSharpFixed {
    base64
    width
    height
    src
    srcSet
  }
`;

/**
 * Traced SVG fixed images
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed = GatsbyImageSharpFixed;
const GatsbyImageSharpFixed_tracedSVG = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed_tracedSVG on ImageSharpFixed {
    tracedSVG
    width
    height
    src
    srcSet
  }
`;

/**
 * Images using Webp for fixed images
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed_tracedSVG = GatsbyImageSharpFixed_tracedSVG;
const GatsbyImageSharpFixed_withWebp = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed_withWebp on ImageSharpFixed {
    base64
    width
    height
    src
    srcSet
    srcWebp
    srcSetWebp
  }
`;

/**
 * Traced SVG images using Webp for fixed images
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed_withWebp = GatsbyImageSharpFixed_withWebp;
const GatsbyImageSharpFixed_withWebp_tracedSVG = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed_withWebp_tracedSVG on ImageSharpFixed {
    tracedSVG
    width
    height
    src
    srcSet
    srcWebp
    srcSetWebp
  }
`;

/**
 * Fixed images without the blurred base64 image
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed_withWebp_tracedSVG = GatsbyImageSharpFixed_withWebp_tracedSVG;
const GatsbyImageSharpFixed_noBase64 = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed_noBase64 on ImageSharpFixed {
    width
    height
    src
    srcSet
  }
`;

/**
 * Fixed images without the blurred base64 image preferring Webp
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed_noBase64 = GatsbyImageSharpFixed_noBase64;
const GatsbyImageSharpFixed_withWebp_noBase64 = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFixed_withWebp_noBase64 on ImageSharpFixed {
    width
    height
    src
    srcSet
    srcWebp
    srcSetWebp
  }
`;

/**
 * The simplest set of fields for fluid images
 * @type {Fragment}
 */
exports.GatsbyImageSharpFixed_withWebp_noBase64 = GatsbyImageSharpFixed_withWebp_noBase64;
const GatsbyImageSharpFluid = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid on ImageSharpFluid {
    base64
    aspectRatio
    src
    srcSet
    sizes
  }
`;

/**
 * Presentation sizes to make sure a fluid container does not overflow
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluid = GatsbyImageSharpFluid;
const GatsbyImageSharpFluidLimitPresentationSize = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluidLimitPresentationSize on ImageSharpFluid {
    maxHeight: presentationHeight
    maxWidth: presentationWidth
  }
`;

/**
 * Traced SVG fluid images
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluidLimitPresentationSize = GatsbyImageSharpFluidLimitPresentationSize;
const GatsbyImageSharpFluid_tracedSVG = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid_tracedSVG on ImageSharpFluid {
    tracedSVG
    aspectRatio
    src
    srcSet
    sizes
  }
`;

/**
 * Fluid images that prefer Webp
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluid_tracedSVG = GatsbyImageSharpFluid_tracedSVG;
const GatsbyImageSharpFluid_withWebp = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid_withWebp on ImageSharpFluid {
    base64
    aspectRatio
    src
    srcSet
    srcWebp
    srcSetWebp
    sizes
  }
`;

/**
 * Traced SVG fluid images that prefer Webp
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluid_withWebp = GatsbyImageSharpFluid_withWebp;
const GatsbyImageSharpFluid_withWebp_tracedSVG = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid_withWebp_tracedSVG on ImageSharpFluid {
    tracedSVG
    aspectRatio
    src
    srcSet
    srcWebp
    srcSetWebp
    sizes
  }
`;

/**
 * Traced SVG fluid images without the blurred base64 image
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluid_withWebp_tracedSVG = GatsbyImageSharpFluid_withWebp_tracedSVG;
const GatsbyImageSharpFluid_noBase64 = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid_noBase64 on ImageSharpFluid {
    aspectRatio
    src
    srcSet
    sizes
  }
`;

/**
 * Traced SVG fluid images without the blurred base64 image that prefer Webp
 * @type {Fragment}
 */
exports.GatsbyImageSharpFluid_noBase64 = GatsbyImageSharpFluid_noBase64;
const GatsbyImageSharpFluid_withWebp_noBase64 = (0, _gatsby.graphql)`
  fragment GatsbyImageSharpFluid_withWebp_noBase64 on ImageSharpFluid {
    aspectRatio
    src
    srcSet
    srcWebp
    srcSetWebp
    sizes
  }
`;
exports.GatsbyImageSharpFluid_withWebp_noBase64 = GatsbyImageSharpFluid_withWebp_noBase64;